# Copyright (C) 2020-2023 MicroSys Electronics GmbH
# Author: Kay Potthoff <kay.potthoff@microsys.de>

require recipes-fsl/images/fsl-image-auto.bb

IMAGE_INSTALL:append:mpxs32g = "${@bb.utils.contains('DISTRO_FEATURES', 'pfe', ' pfe ', '', d)}"
IMAGE_INSTALL:append:mpxs32g = "${@bb.utils.contains('DISTRO_FEATURES', 'sja1110', ' sja1110 ', '', d)}"
IMAGE_INSTALL:append = " vlan "

IMAGE_INSTALL:append = " arm-trusted-firmware "

IMAGE_INSTALL:append = "${@bb.utils.contains('DISTRO_FEATURES', 'wifi', ' hostapd kea ', '', d)}"

IMAGE_INSTALL:append = "${@bb.utils.contains('DISTRO_FEATURES', 'docker', ' docker-ce ', '', d)}"

MACHINE_ESSENTIAL_EXTRA_RRECOMMENDS:mpxs32g += "${@bb.utils.contains('DISTRO_FEATURES', \
    'wifi', \
    ' linux-firmware-rtw88 \
      linux-firmware-ath10k \
      kernel-module-rtw88-8822ce \
      kernel-module-rtw88-8822c \
      kernel-module-rtw88-core \
      kernel-module-rtw88-pci \
      kernel-module-ath \
      kernel-module-ath10k \
      kernel-module-ath10k-core ' \
    '', d)}"

MACHINE_ESSENTIAL_EXTRA_RRECOMMENDS:mpxs32g += "kernel-module-pfe"
MACHINE_ESSENTIAL_EXTRA_RRECOMMENDS:mpxs32g += "${@bb.utils.contains('DISTRO_FEATURES', \
    'sja1110', 'kernel-module-sja1110', '', d)}"
MACHINE_ESSENTIAL_EXTRA_RRECOMMENDS:mpxs32g += "${@bb.utils.contains('DISTRO_FEATURES', \
    'hailo', 'kernel-module-hailo-pci', '', d)}"

MICROSYS_IMAGE_EXTRA_INSTALL += " \
    parted e2fsprogs-resize2fs bashprofile \
    linux-s32-tools libgpiod libgpiod-tools libgpiod-python libgpiodcxx \
    stressapptest \
"

MICROSYS_IMAGE_EXTRA_INSTALL += "${@bb.utils.contains('DISTRO_FEATURES', \
                                   'systemd', 'systemd pm-utils', '', d)}"

IMAGE_INSTALL += "${MICROSYS_IMAGE_EXTRA_INSTALL}"

IMAGE_INSTALL:remove = "kernel-devicetree"
IMAGE_INSTALL:remove = "gnuplot"
IMAGE_INSTALL:remove = "kernel-pcitest"
IMAGE_INSTALL:remove = "aquantia-firmware-utility"
IMAGE_INSTALL:remove = "irqbalance"

# Hailo support
# Recipes from meta-hailo-accelerator:
IMAGE_INSTALL:append = "${@bb.utils.contains('DISTRO_FEATURES', \
    'hailo', \
    ' hailo-pci hailo-firmware ', \
    '', d)}"

# Recipes from meta-hailo-libhailort:
#IMAGE_INSTALL:append = "${@bb.utils.contains('DISTRO_FEATURES', \
#    'hailo', \
#    ' hailortcli libhailort pyhailort pyhailort-shared ', \
#    '', d)}"
#IMAGE_INSTALL:append = "${@bb.utils.contains('DISTRO_FEATURES', \
#    'hailo', \
#    ' python3-distlib python3-verboselogs ', \
#    '', d)}"
#IMAGE_INSTALL:append = "${@bb.utils.contains('DISTRO_FEATURES', \
#    'hailo', \
#    ' libgsthailo ', \
#    '', d)}"

# Recipes from meta-hailo-tappas:
#IMAGE_INSTALL:append = "${@bb.utils.contains('DISTRO_FEATURES', \
#    'hailo', \
#    ' xtl hailo-post-processes libgsthailotools tappas-apps rapidjson xtensor cxxopts ', \
#    '', d)}"

SDCARD_ROOTFS = "${IMGDEPLOYDIR}/${IMAGE_BASENAME}-${MACHINE}.ext4"

DEPENDS += "parted-native u-boot"
DEPENDS += "arm-trusted-firmware"

do_image_ext4[depends] += "e2fsprogs-native:do_populate_sysroot"
do_image_ext3[depends] += "e2fsprogs-native:do_populate_sysroot"
do_image_sdcard[deptask] += "do_rootfs"
do_image_sdcard[deptask] += "do_image_ext4"
do_image_sdcard[deptask] += "do_image_qspi"
do_rootfs_kernelitb[deptask] += "virtual/kernel:do_deploy"
do_image_sdcard[depends] += "arm-trusted-firmware:do_deploy"
do_image_qspi[depends] += "arm-trusted-firmware:do_deploy"

IMAGE_FSTYPES:remove = "cpio.gz.u-boot"
IMAGE_FSTYPES:remove = "ext3"
IMAGE_FSTYPES += "ext4"
IMAGE_FSTYPES:append:mpxs32g = " qspi"

do_rootfs_kernelitb() {
    :
    #cp -a ${DEPLOY_DIR_IMAGE}/fitImage*.itb ${IMAGE_ROOTFS}/boot
    #cp -a ${DEPLOY_DIR_IMAGE}/Image.gz ${IMAGE_ROOTFS}/boot
}
addtask rootfs_kernelitb after do_rootfs before do_image

do_rootfs_firmware() {
}

do_rootfs_firmware:mpxs32g() {
    :
    # PFE firmware:
    # cp -a ${DEPLOY_DIR_IMAGE}/${SDCARDIMAGE_BOOT_EXTRA2_FILE} ${IMAGE_ROOTFS}

    # QSPI U-Boot:
    #mkdir -p ${IMAGE_ROOTFS}/boot
    #cp ${DEPLOY_DIR_IMAGE}/${FLASHIMAGE_UBOOT_FILE} ${IMAGE_ROOTFS}/boot
}
addtask rootfs_firmware after do_rootfs before do_image
